/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#include "main.h"
//#include "wvbStatusChar.h"
//#include "wvbConfigurationChar.h"
//#include "BLEApplications.h"
#include "wvWDT.h"

volatile bool logIMU;
volatile bool logPOX;
volatile bool logMilestone;

uint32 milestoneCount		= 0;

uint32 wdt_timer_interval;

// LED counter
uint16 currentLEDCount		= 0;
uint16 gooberCount			= 0;
uint16 epochCount			= 0;
uint16 blinkLEDCount		= 0;
bool doLEDBlink				= false;


void bleBlinkLED(void) {
	doLEDBlink			= true;
	blinkLEDCount		= 0;
}


/*******************************************************************************
 * Function Name: Timer_Interrupt
 ********************************************************************************
 *
 * Summary:
 *  Handles the Interrupt Service Routine for the WDT timer.
 *
 *******************************************************************************/
CY_ISR(Timer_Interrupt) {
	if(CySysWdtGetInterruptSource() & WDT_INTERRUPT_SOURCE) {

		CySysWdtClearInterrupt(WDT_INTERRUPT_SOURCE);	// Clear the IRQ

		epochCount++;
		if (epochCount == 1000) {
			//statusCharUpdateEpoch();
			epochCount	= 0;
		}

		if (deviceConnected) {
			currentLEDCount = 0;

			//if (sendBatteryNotification == false) {
			//	gooberCount++;
			//	if (gooberCount == 5000) {
			//		gooberCount = 0;
			//		sendBatteryNotification = true;
			//	}
			//}
		}
		else {
			gooberCount	= 0;

			currentLEDCount	+= 1;
			if (currentLEDCount == 1000) {
				//LED On
				LED_Write(LED_ON);
			}
			else if (currentLEDCount == 2000) {
				//LED Off
				currentLEDCount = 0;
				LED_Write(LED_OFF);
			}
		}

		// Logging timers...
		milestoneCount++;
		if ((milestoneCount % 100) == 0) {
		//	DBG_PRINTF ("Trigger IMU log\r\n");
			logIMU			= true;
		}

		if ((milestoneCount % 20000) == 0) {
		//	DBG_PRINTF ("Trigger POX log\r\n");
			//logPOX			= true;
		}

		if (milestoneCount == 60000) {
		//	DBG_PRINTF ("Trigger Milestone log\r\n");
			milestoneCount	= 0;
			logMilestone	= true;
		}
	}
}

/*******************************************************************************
 * Function Name: WDT_Start
 ********************************************************************************
 *
 * Summary:
 *  Configures WDT to trigger an interrupt.
 *
 *******************************************************************************/

void WDT_Start(void)
{
	/* Unlock the WDT registers for modification */
	CySysWdtUnlock();
	/* Setup ISR */
	WDT_Interrupt_StartEx(&Timer_Interrupt);
	/* Write the mode to generate interrupt on match */
	CySysWdtWriteMode(WDT_COUNTER, CY_SYS_WDT_MODE_INT);
	/* Configure the WDT counter clear on a match setting */
	CySysWdtWriteClearOnMatch(WDT_COUNTER, WDT_COUNTER_ENABLE);
	/* Configure the WDT counter match comparison value */
	wdt_timer_interval = WDT_TIMEOUT * 1000 / 32768 + 1;
	CySysWdtWriteMatch(WDT_COUNTER, WDT_TIMEOUT);
	/* Reset WDT counter */
	CySysWdtResetCounters(WDT_COUNTER);
	/* Enable the specified WDT counter */
	CySysWdtEnable(WDT_COUNTER_MASK);
	/* Lock out configuration changes to the Watchdog timer registers */
	CySysWdtLock();
}


/*******************************************************************************
 * Function Name: WDT_SetInterval
 ********************************************************************************
 *
 * Summary:
 *  Changes watchdog interval
 *
 *******************************************************************************/

void WDT_SetInterval(uint32 wdt_timeout)
{
	/* Unlock the WDT registers for modification */
	CySysWdtUnlock();
	/* Disable the specified WDT counter */
	CySysWdtDisable(WDT_COUNTER_MASK);
	/* Configure the WDT counter match comparison value */
	wdt_timer_interval = wdt_timeout * 1000 / 32768 + 1;
	CySysWdtWriteMatch(WDT_COUNTER, wdt_timeout);
	/* Reset WDT counter */
	CySysWdtResetCounters(WDT_COUNTER);
	/* Enable the specified WDT counter */
	CySysWdtEnable(WDT_COUNTER_MASK);
	CySysWdtLock();
}

/*******************************************************************************
 * Function Name: WDT_Stop
 ********************************************************************************
 *
 * Summary:
 *  This API stops the WDT timer.
 *
 *******************************************************************************/
void WDT_Stop(void)
{
	// Unlock the WDT registers for modification
	CySysWdtUnlock();
	// Disable the specified WDT counter
	CySysWdtDisable(WDT_COUNTER_MASK);
	// Locks out configuration changes to the Watchdog timer registers
	CySysWdtLock();
}
