/*******************************************************************************
* File Name: debug.h
*
* Version: 1.50
*
* Description:
*  Provides debug API.
*
* Hardware Dependency:
*  CY8CKIT-042 BLE
*
********************************************************************************
* Copyright 2014-2016, Cypress Semiconductor Corporation. All rights reserved.
* This software is owned by Cypress Semiconductor Corporation and is protected
* by and subject to worldwide patent and copyright laws and treaties.
* Therefore, you may use this software only as provided in the license agreement
* accompanying the software package from which you obtained this software.
* CYPRESS AND ITS SUPPLIERS MAKE NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
* WITH REGARD TO THIS SOFTWARE, INCLUDING, BUT NOT LIMITED TO, NONINFRINGEMENT,
* IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
*******************************************************************************/

#ifndef BLE_OTA_EM_DEBUG_H_
#define BLE_OTA_EM_DEBUG_H_

#include <stdio.h>
#include "options.h"
	
#if (DEBUG_UART_ENABLED == YES) || (MIN_DEBUG_UART_ENABLED == YES)
	#define MDBG_PRINT_TEXT(a)        do\
                                        {\
                                            printf((a));\
                                        } while (0)

    #define MDBG_PRINT_DEC(a)         do\
                                        {\
                                           printf("%02d ", a);\
                                        } while (0)


    #define MDBG_PRINT_HEX(a)         do\
                                        {\
                                           printf("%08X ", a);\
                                        } while (0)


    #define MDBG_PRINT_ARRAY(a,b)     do\
                                        {\
                                            uint32 i;\
                                            \
                                            for(i = 0u; i < (b); i++)\
                                            {\
                                                printf("%02X ", *(a+i));\
                                            }\
                                        } while (0)

    #define MDBG_PRINTF(...)          (printf(__VA_ARGS__))
    
    #define MDBG_NEW_PAGE             UART_PutChar(0x0C)
#else
    #define MDBG_PRINT_TEXT(a)
    #define MDBG_PRINT_DEC(a)
    #define MDBG_PRINT_HEX(a)
    #define MDBG_PRINT_ARRAY(a,b)
    #define MDBG_PRINTF(...)
    #define MDBG_NEW_PAGE
#endif

#if (DEBUG_UART_ENABLED == YES)
    #define DBG_PRINT_TEXT(a)        do\
                                        {\
                                            printf((a));\
                                        } while (0)

    #define DBG_PRINT_DEC(a)         do\
                                        {\
                                           printf("%02d ", a);\
                                        } while (0)


    #define DBG_PRINT_HEX(a)         do\
                                        {\
                                           printf("%08X ", a);\
                                        } while (0)


    #define DBG_PRINT_ARRAY(a,b)     do\
                                        {\
                                            uint32 i;\
                                            \
                                            for(i = 0u; i < (b); i++)\
                                            {\
                                                printf("%02X ", *(a+i));\
                                            }\
                                        } while (0)

    #define DBG_PRINTF(...)          (printf(__VA_ARGS__))
    
    #define DBG_NEW_PAGE             UART_PutChar(0x0C)
    
    
#else
    #define DBG_PRINT_TEXT(a)
    #define DBG_PRINT_DEC(a)
    #define DBG_PRINT_HEX(a)
    #define DBG_PRINT_ARRAY(a,b)
    #define DBG_PRINTF(...)
    #define DBG_NEW_PAGE             
#endif /* (DEBUG_UART_ENABLED == YES) */

#endif /* BLE_OTA_EM_DEBUG_H_ */

/* [] END OF FILE */
