/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/

#include "ota_flash.h"


int ota_read_id( void ) {
	//Tests whether there is a winbond chip listening
	uint8 buffer[16];
	
	buffer[0] = 0x90; //Read manufacturer ID
	buffer[1] = 0;
	buffer[2] = 0;
	buffer[3] = 0;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 6);
	
	F_SS_Write(1);
	
	if (buffer[4] != 0xEF) {
		return 0;
	} else {
		return buffer[5];
	}	
	
}

void ota_write_buf(uint32 dataAddr, uint8 *data, uint32 dataSize) {
	
	uint32 pageAddr = dataAddr & ~(OTA_PAGE_SIZE-1);
	
	if (dataSize != OTA_PAGE_SIZE) {
		
		DBG_PRINTF("datasize %lx != WINBOND_PAGE_SIZE\r\n", dataSize);
		
		return;
	}
	
	ota_program_page(pageAddr, data, dataSize);	
}

void ota_program_page(uint32 pageAddr, uint8 *data, uint32 dataSizeLeft) {
	uint8 buffer[16];
	uint8 status;
		
	//winbond_page_erase(pageAddr);  //Erase the page
    //DBG_PRINTF ("Page: %08lX, ", (pageAddr - 0x100) >> 8);
    //DBG_PRINT_ARRAY (data, WINBOND_PAGE_SIZE);
    //DBG_PRINTF ("\r\n");
    
    // Put the first page that isn't page 0 (the metadata) onto it's own sector
    //DBG_PRINTF ("ota_program_page() -> pageAddr (was) %08lX : ", pageAddr);
    if (pageAddr != 0u) {
//		pageAddr = pageAddr + (15 * OTA_PAGE_SIZE);
        pageAddr = pageAddr << 4;
    }
    //DBG_PRINTF ("(is) %08lX\r\n", pageAddr);
    
    if ((pageAddr & (OTA_SECTOR_SIZE - 1)) == 0) {	// Pointing to a new sector
		DBG_PRINTF ("Erase sector: %08lX\r\n", pageAddr);
		ota_page_erase(pageAddr);
	}
	
	ota_write_enable();
	
	buffer[0] = 0x02;	//Page program
	buffer[1] = (pageAddr>>16) & 0xFF;
	buffer[2] = (pageAddr>>8) & 0xFF; 
	buffer[3] = (pageAddr) & 0xFF;
	
	F_SS_Write(0);
	spiExchange(buffer, 4);
	spiExchange(data, dataSizeLeft);  //Program entire page
	F_SS_Write(1);
	
	while (1) {
		CyDelay(1);
		
		status = ota_read_status();
		if ( (status & OTA_STATUS_BUSY) != OTA_STATUS_BUSY) {
			break;
		}
	}

	return;
	
	
}

void ota_read_page(uint32 pageAddr, uint8 *data, uint32 dataSizeLeft) {
	uint8 buffer[16];
    
    // Put the first page that isn't page 0 (the metadata) onto it's own sector
    //MDBG_PRINTF ("ota_read_page()    -> pageAddr (was) %08lX : ", pageAddr);
    if (pageAddr != 0u) {
//		pageAddr = pageAddr + (15 * OTA_PAGE_SIZE);
		pageAddr = pageAddr << 4;
    }
    //MDBG_PRINTF ("(is) %08lX\r\n", pageAddr);
	
	buffer[0] = 0x03;
	buffer[1] = (pageAddr>>16) & 0xFF;
	buffer[2] = (pageAddr>>8) & 0xFF;
	buffer[3] = (pageAddr) & 0xFF;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 4);
	spiExchange(data, dataSizeLeft);
	
	F_SS_Write(1);
    
    //DBG_PRINTF ("Page Address: %08lX, ", pageAddr);
    //DBG_PRINT_ARRAY (data, dataSizeLeft);
    //DBG_PRINTF ("\r\n");    
}


void ota_read_buf(uint32 dataAddr, uint8 *data, uint32 dataSize) {
	if (dataSize == 0) {
		return;
	}
	
	ota_read_page(dataAddr, data, dataSize);
		
			
}

void ota_page_erase(uint32 pageAddr) {
	uint8 buffer[16];
	uint8 status;
	

	ota_write_enable();
	
	//Execute sector erase
	buffer[0] = 0x20;
	buffer[1] = (pageAddr>>16) & 0xFF;
	buffer[2] = (pageAddr>>8) & 0xFF;
	buffer[3] = (pageAddr) & 0xFF;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 4);
	
	F_SS_Write(1);
	
	while (1) {
		CyDelay(10);
		
		status = ota_read_status();
		if ( (status & OTA_STATUS_BUSY) != OTA_STATUS_BUSY) {
			break;
		}
	}

	
}

void pta_block_erase_64(uint32 blockAddr) {
	uint8 buffer[16];
	uint8 status;
	

	ota_write_enable();
	
	//Execute block erase 64K size
	buffer[0] = 0xD8;
	buffer[1] = (blockAddr>>16) & 0xFF;
	buffer[2] = (blockAddr>>8) & 0xFF;
	buffer[3] = (blockAddr) & 0xFF;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 4);
	
	F_SS_Write(1);
	
	while (1) {
		CyDelay(10);
		
		status = ota_read_status();
		if ( (status & OTA_STATUS_BUSY) != OTA_STATUS_BUSY) {
			break;
		}
	}

	
}

void ota_start_block_erase_64(uint32 blockAddr) {
	uint8 buffer[16];
	

	ota_write_enable();
	
	//Execute block erase 64K size
	buffer[0] = 0xD8;
	buffer[1] = (blockAddr>>16) & 0xFF;
	buffer[2] = (blockAddr>>8) & 0xFF; 
	buffer[3] = (blockAddr) & 0xFF;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 4);
	
	F_SS_Write(1);
	
		
}


void ota_chip_erase( void ) { 
	uint8 buffer[16];
	uint8 status;
	
	while (1) {
	
		ota_write_enable();
		
		//Execute chip erase
		buffer[0] = 0xC7;
		
		F_SS_Write(0);
		
		spiExchange(buffer, 1);
		
		F_SS_Write(1);
		
		CyDelay(1);
		
		status = ota_read_status();
		if ( (status & OTA_STATUS_BUSY) != OTA_STATUS_BUSY) {
			continue;
		}		
	
		while (1) {
			CyDelay(1000);
			
			status = ota_read_status();
			if ( (status & OTA_STATUS_BUSY) != OTA_STATUS_BUSY) {
				break;
			}
		}
	
		break;
	}
}

void ota_start_erase( void ) { 
	uint8 buffer[16];
	
	//Non-blocking
	ota_write_enable();
	
	//Execute chip erase
	buffer[0] = 0xC7;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 1);
	
	F_SS_Write(1);
		
}


void ota_write_enable( void ) {
	uint8 buffer[16];
	
	buffer[0] = 0x06;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 1);
	
	F_SS_Write(1);
	
	
}

uint8 ota_read_status( void ) {
	uint8 buffer[16];
	
	buffer[0] = 0x05;
	buffer[1] = 0xFF;
	
	F_SS_Write(0);
	
	spiExchange(buffer, 2);
	
	F_SS_Write(1);
	
	return buffer[1];
	
}




/* [] END OF FILE */
